fixpoint

Function fixpoint 

pub fn fixpoint(float: f64, unit_opt: Option<f64>) -> i64
Convert float to a fixed-point number

If unit is given, it is number of units PER SCALED-POINT! (hence, extra division) AND, note that the float is rounded and THEN truncated after multiplying by units! to mimic TeX’s behavior.